from setuptools import setup
setup(
    name="trStr",
    packages=['trStr'],
    version="1.0.1",
    license='MIT',
    description="String methods for Turkish characters",
    long_description=open('README.md').read(),
    author="Muhammet Fatih DİNÇ",
    author_email="mfatihdinc61@gmail.com",
    url="https://seridilekce.com",
    keywords=['turkish', 'string', 'upper'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
)
